"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cloner_1 = require("../lib/cloner");
const github_1 = require("../lib/github");
const log_1 = require("../lib/log");
const scanner_1 = require("../lib/scanner");
class Scan extends command_1.Command {
    async run() {
        const { flags } = this.parse(Scan);
        const log = log_1.createLogger(flags.createLogFiles, flags.outputDir);
        if (flags.githubOrgName) {
            // create a temp directory to clone into
            const cloneDir = cloner_1.tempDir();
            // set the scan context
            const ctx = {
                log,
                rootDirectory: cloneDir,
                redactValues: flags.redact,
            };
            // clone all organisation repositories
            const repos = await github_1.orgRepoUrls(ctx, flags.githubOrgName);
            log.info(`about to clone ${repos.length} repositories`);
            let cloned = 0;
            for (const repo of repos) {
                try {
                    await cloner_1.clone(ctx, repo);
                    cloned++;
                }
                catch (e) {
                    log.error(`failed to clone ${repo}`);
                }
            }
            log.info(`cloned ${cloned} of ${repos.length} repositories`);
            // run a scan on all repositories in the temp directory
            await scanner_1.run(ctx);
            // we don't need this temp directory anymore
            cloner_1.rmDirSync(cloneDir);
            return;
        }
        await scanner_1.run({
            log,
            rootDirectory: flags.dir || ".",
            redactValues: flags.redact,
        });
    }
}
exports.default = Scan;
Scan.description = "scans local git repositories for committed secrets";
Scan.examples = ["$ git-secret-scanner scan ~/code/github.com/my-org -r"];
Scan.flags = {
    help: command_1.flags.help({ char: "h" }),
    dir: command_1.flags.string({
        char: "d",
        description: "directory to scan (current direction if omitted)",
        exclusive: ["url"],
    }),
    redact: command_1.flags.boolean({
        char: "r",
        description: "redact all matched secret strings",
    }),
    githubOrgName: command_1.flags.string({
        char: "g",
        description: "clone all repositories from this GitHub org",
        exclusive: ["dir"],
    }),
    createLogFiles: command_1.flags.boolean({
        char: "l",
        description: "create log files",
    }),
    outputDir: command_1.flags.string({
        char: "o",
        description: "output directory (log files)",
    }),
};
